[jboss-cvs] JBossAS SVN: r82972 - projects/ejb3/trunk/proxy/src/main/java/org/jboss/ejb3/proxy/jndiregistrar.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Fri Jan 16 03:40:23 EST 2009


Author: ALRubinger
Date: 2009-01-16 03:40:23 -0500 (Fri, 16 Jan 2009)
New Revision: 82972

Modified:
   projects/ejb3/trunk/proxy/src/main/java/org/jboss/ejb3/proxy/jndiregistrar/JndiSessionRegistrarBase.java
Log:
[EJBTHREE-1688] Fix the regression

Modified: projects/ejb3/trunk/proxy/src/main/java/org/jboss/ejb3/proxy/jndiregistrar/JndiSessionRegistrarBase.java
===================================================================
--- projects/ejb3/trunk/proxy/src/main/java/org/jboss/ejb3/proxy/jndiregistrar/JndiSessionRegistrarBase.java	2009-01-16 08:40:04 UTC (rev 82971)
+++ projects/ejb3/trunk/proxy/src/main/java/org/jboss/ejb3/proxy/jndiregistrar/JndiSessionRegistrarBase.java	2009-01-16 08:40:23 UTC (rev 82972)
@@ -980,6 +980,14 @@
             // Not bound together
             return false;
          }
+         
+         // If no business locals defined
+         BusinessLocalsMetaData businessLocals = smd.getBusinessLocals();
+         if (businessLocals == null || businessLocals.size() == 0)
+         {
+            // Not bound together
+            return false;
+         }
 
          // Bind together if Local Default JNDI Name == Local Home JNDI Name
          bindTogether = smd.getLocalJndiName().equals(smd.getLocalHomeJndiName());
@@ -993,7 +1001,16 @@
             // Not bound together
             return false;
          }
-         // Bind together if Local Default JNDI Name == Local Home JNDI Name
+         
+         // If no business remotes defined
+         BusinessRemotesMetaData businessRemotes = smd.getBusinessRemotes();
+         if (businessRemotes == null || businessRemotes.size() == 0)
+         {
+            // Not bound together
+            return false;
+         }
+         
+         // Bind together if Remote Default JNDI Name == Remote Home JNDI Name
          bindTogether = smd.getJndiName().equals(smd.getHomeJndiName());
       }
 




More information about the jboss-cvs-commits mailing list